ged4py.detail package
=====================

Submodules
----------

.. toctree::

   ged4py.detail.date
   ged4py.detail.io
   ged4py.detail.name

Module contents
---------------

.. automodule:: ged4py.detail
   :members:
   :undoc-members:
   :show-inheritance:
